myFUN_ggplotRegression: A regression FUnction

Description Usage Arguments Examples

Description

This function allows to plot a regression with all wanted values

Usage

1

Arguments

fit

is the before runed lm model which you want to plot now

Examples

1

agroflavian/funGLEIS documentation built on May 16, 2019, 4:54 p.m.